@@ -1,13 +1,10 @@
 # Copyright (C) 2019 Nir Soffer
 # SPDX-License-Identifier: GPL-2.0-or-later
 
-from __future__ import absolute_import
-from __future__ import division
-
 import argparse
 import logging
 
-from . import backend
+from . import errors
 from . import config
 from . import osutil
 
@@ -50,7 +47,7 @@ def create(cfg):
     for b in cfg.BACKENDS.values():
         try:
             b.create()
-        except backend.Error as e:
+        except errors.Error as e:
             if b.required:
                 raise
             log.warning("Skipping %s storage: %s", b.name, e)
