@@ -1,9 +1,6 @@
 # Copyright (C) 2019 Nir Soffer
 # SPDX-License-Identifier: GPL-2.0-or-later
 
-from __future__ import absolute_import
-from __future__ import division
-
 import os
 import logging
 
